@@ -39,6 +39,7 @@ WeatherLocation::WeatherLocation(QString locationId,
     this->m_timer->start(60 - QDateTime::currentDateTime().currentMSecsSinceEpoch() % 60);
 
     m_lastUpdated = forecast.createdTime();
+    Q_EMIT lastUpdatedChanged();
 
     update();
 
@@ -55,6 +56,11 @@ WeatherLocation::WeatherLocation(QString locationId,
         Q_EMIT hourForecastsChanged();
     });
 }
+
+WeatherLocation::WeatherLocation()
+{
+}
+
 WeatherLocation *WeatherLocation::load(const QString &groupName)
 {
     auto config = KWeatherSettings::self()->config()->group(Kweather::WEATHER_LOCATIONS_CFG_GROUP).group(groupName);
@@ -107,14 +113,16 @@ void WeatherLocation::updateData(KWeatherCore::WeatherForecast forecasts)
     // first time the timezone is empty
     if (m_timeZone.isEmpty()) {
         m_timeZone = forecasts.timezone();
+        Q_EMIT timeZoneChanged();
         save();
     }
 
     determineCurrentForecast();
     m_lastUpdated = forecasts.createdTime();
+    Q_EMIT lastUpdatedChanged();
 
     m_hourForecasts.clear();
-    if (!m_forecast.dailyWeatherForecast().empty()) {
+    if (!m_forecast.dailyWeatherForecast().empty() && m_forecast.dailyWeatherForecast().size() > m_selectedDay) {
         const auto hourForecasts = m_forecast.dailyWeatherForecast()[m_selectedDay].hourlyWeatherForecast();
         for (const KWeatherCore::HourlyWeatherForecast &hour : hourForecasts) {
             m_hourForecasts << QVariant::fromValue(hour);
@@ -131,7 +139,6 @@ void WeatherLocation::updateData(KWeatherCore::WeatherForecast forecasts)
     Q_EMIT weatherRefresh(m_forecast);
     Q_EMIT stopLoadingIndicator();
 
-    Q_EMIT propertyChanged();
     updateCurrentDateTime();
 }
 
@@ -195,6 +202,7 @@ void WeatherLocation::determineCurrentForecast()
     if (isDayStyle) {
         m_cardBackgroundColor = QStringLiteral("#fefefe");
         m_cardTextColor = QStringLiteral("black");
+        m_cardSecondaryTextColor = QStringLiteral("#404040");
         m_backgroundColor = QStringLiteral("#3daee2");
         m_textColor = m_cardTextColor;
         m_iconColor = QStringLiteral("#4d4d4d");
@@ -202,12 +210,13 @@ void WeatherLocation::determineCurrentForecast()
     } else {
         m_cardBackgroundColor = QStringLiteral("#333333");
         m_cardTextColor = QStringLiteral("#eeeeee");
+        m_cardSecondaryTextColor = QStringLiteral("#C2C2C2");
         m_backgroundColor = QStringLiteral("#222222");
         m_textColor = m_cardTextColor;
         m_iconColor = QStringLiteral("white");
         m_isDarkTheme = true;
     }
-    Q_EMIT currentForecastChange();
+    Q_EMIT currentForecastChanged();
 }
 
 void WeatherLocation::update()
@@ -229,11 +238,3 @@ void WeatherLocation::updateCurrentDateTime()
     Q_EMIT currentTimeChanged();
     Q_EMIT currentDateChanged();
 }
-
-KWeatherCore::DailyWeatherForecast WeatherLocation::todayForecast() const
-{
-    if (!m_dayForecasts.isEmpty()) {
-        return m_dayForecasts.first().value<KWeatherCore::DailyWeatherForecast>();
-    }
-    return {};
-}
