@@ -15,6 +15,7 @@
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QObject>
+#include <QString>
 #include <QTimeZone>
 #include <QTimer>
 
@@ -33,30 +34,33 @@ class QValueAxis;
 class WeatherLocation : public QObject
 {
     Q_OBJECT
-    Q_PROPERTY(QString name READ locationName NOTIFY propertyChanged)
-    Q_PROPERTY(QString lastUpdated READ lastUpdatedFormatted NOTIFY propertyChanged)
+    Q_PROPERTY(QString name READ locationName CONSTANT)
+    Q_PROPERTY(QString lastUpdated READ lastUpdatedFormatted NOTIFY lastUpdatedChanged)
     Q_PROPERTY(QString currentTime READ currentTimeFormatted NOTIFY currentTimeChanged)
     Q_PROPERTY(QString currentDate READ currentDateFormatted NOTIFY currentDateChanged)
+    Q_PROPERTY(QString timeZone READ timeZone NOTIFY timeZoneChanged)
     Q_PROPERTY(QVariantList dayForecasts READ dayForecasts NOTIFY dayForecastsChanged)
     Q_PROPERTY(QVariantList hourForecasts READ hourForecasts NOTIFY hourForecastsChanged)
     Q_PROPERTY(int selectedDay READ selectedDay WRITE setSelectedDay NOTIFY selectedDayChanged)
-    Q_PROPERTY(KWeatherCore::DailyWeatherForecast todayForecast READ todayForecast NOTIFY dayForecastsChanged)
 
-    Q_PROPERTY(QString backgroundComponent READ backgroundComponent NOTIFY currentForecastChange)
-    Q_PROPERTY(QColor backgroundColor READ backgroundColor NOTIFY currentForecastChange)
-    Q_PROPERTY(QColor textColor READ textColor NOTIFY currentForecastChange)
-    Q_PROPERTY(QColor cardBackgroundColor READ cardBackgroundColor NOTIFY currentForecastChange)
-    Q_PROPERTY(QColor cardTextColor READ cardTextColor NOTIFY currentForecastChange)
-    Q_PROPERTY(QColor iconColor READ iconColor NOTIFY currentForecastChange)
-    Q_PROPERTY(bool darkTheme READ darkTheme NOTIFY currentForecastChange)
+    Q_PROPERTY(QString backgroundComponent READ backgroundComponent NOTIFY currentForecastChanged)
+    Q_PROPERTY(QColor backgroundColor READ backgroundColor NOTIFY currentForecastChanged)
+    Q_PROPERTY(QColor textColor READ textColor NOTIFY currentForecastChanged)
+    Q_PROPERTY(QColor cardBackgroundColor READ cardBackgroundColor NOTIFY currentForecastChanged)
+    Q_PROPERTY(QColor cardTextColor READ cardTextColor NOTIFY currentForecastChanged)
+    Q_PROPERTY(QColor cardSecondaryTextColor READ cardSecondaryTextColor NOTIFY currentForecastChanged)
+    Q_PROPERTY(QColor iconColor READ iconColor NOTIFY currentForecastChanged)
+    Q_PROPERTY(bool darkTheme READ darkTheme NOTIFY currentForecastChanged)
 
 public:
     explicit WeatherLocation(QString locationId,
                              QString locationName,
                              QString timeZone,
-                             float latitude,
-                             float longitude,
+                             float latitude = 0,
+                             float longitude = 0,
                              KWeatherCore::WeatherForecast forecast = {});
+    explicit WeatherLocation(); // when creating empty locations, don't persist
+
     void save();
     static WeatherLocation *load(const QString &groupName);
     Q_INVOKABLE void update();
@@ -101,11 +105,6 @@ public:
     {
         return QDateTime::currentDateTime().toTimeZone(QTimeZone(m_timeZone.toUtf8()));
     }
-    void setLastUpdated(QDateTime lastUpdated)
-    {
-        m_lastUpdated = std::move(lastUpdated);
-        Q_EMIT propertyChanged();
-    }
     const QString &backgroundComponent() const
     {
         return m_backgroundComponent;
@@ -126,6 +125,10 @@ public:
     {
         return m_cardTextColor;
     };
+    const QColor &cardSecondaryTextColor() const
+    {
+        return m_cardSecondaryTextColor;
+    }
 
     const QColor &iconColor() const
     {
@@ -154,7 +157,6 @@ public:
             Q_EMIT selectedDayChanged();
         }
     }
-    KWeatherCore::DailyWeatherForecast todayForecast() const;
 
     // for restore order of locations
     void saveOrder(int index);
@@ -165,14 +167,15 @@ public Q_SLOTS:
 
 Q_SIGNALS:
     void weatherRefresh(KWeatherCore::WeatherForecast forecasts); // sent when weather data is refreshed
-    void currentForecastChange();
-    void propertyChanged(); // avoid warning
+    void currentForecastChanged();
     void stopLoadingIndicator();
     void currentTimeChanged();
     void currentDateChanged();
+    void timeZoneChanged();
     void dayForecastsChanged();
     void hourForecastsChanged();
     void selectedDayChanged();
+    void lastUpdatedChanged();
 
     void chartListChanged();
 private Q_SLOTS:
@@ -189,6 +192,7 @@ private:
     QColor m_textColor;
     QColor m_cardBackgroundColor;
     QColor m_cardTextColor;
+    QColor m_cardSecondaryTextColor;
     QColor m_iconColor;
     QString m_backgroundComponent = QStringLiteral("backgrounds/ClearDay.qml");
     bool m_isDarkTheme = false;
